==> jc-1.4.0.tar.gz: soot/jimple/parser/node/TDiv.h <==
// public final class soot.jimple.parser.node.TDiv

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 8c6cb1486af16725 soot_jimple_parser_node_TDiv
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TDiv_H_
#define _JC_soot_jimple_parser_node_TDiv_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TDiv$sub_refs	_jc_soot_jimple_parser_node_TDiv$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TDiv$sub_nonrefs	_jc_soot_jimple_parser_node_TDiv$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TDiv$refs	_jc_soot_jimple_parser_node_TDiv$refs;
typedef struct _jc_soot_jimple_parser_node_TDiv$nonrefs	_jc_soot_jimple_parser_node_TDiv$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TDiv$object	_jc_soot_jimple_parser_node_TDiv$object;

typedef const struct _jc_soot_jimple_parser_node_TDiv$vmethods	_jc_soot_jimple_parser_node_TDiv$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TDiv$vtable	_jc_soot_jimple_parser_node_TDiv$vtable;
typedef const struct _jc_soot_jimple_parser_node_TDiv$vtype	_jc_soot_jimple_parser_node_TDiv$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TDiv$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *);
extern void _jc_soot_jimple_parser_node_TDiv$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, jint, jint);

// Virtual methods
extern void _jc_soot_jimple_parser_node_TDiv$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TDiv$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *);
extern void _jc_soot_jimple_parser_node_TDiv$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TDiv$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TDiv$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_TDiv$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TDiv$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *);
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_TDiv$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TDiv$vmethods	soot_jimple_parser_node_TDiv;
};

// Vtype
struct _jc_soot_jimple_parser_node_TDiv$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TDiv$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TDiv$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TDiv$refs {
    _jc_soot_jimple_parser_node_TDiv$sub_refs	soot_jimple_parser_node_TDiv;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TDiv$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TDiv$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TDiv$sub_nonrefs	soot_jimple_parser_node_TDiv;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TDiv$object {
	_jc_soot_jimple_parser_node_TDiv$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TDiv$vtype	*vtype;
	_jc_soot_jimple_parser_node_TDiv$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TDiv$vtype _jc_soot_jimple_parser_node_TDiv$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TDiv, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TDiv$class_object;

#endif	/* _JC_soot_jimple_parser_node_TDiv_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/TDiv.h <==
// public final class soot.jimple.parser.node.TDiv

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 8c6cb1486af16725 soot_jimple_parser_node_TDiv
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TDiv_H_
#define _JC_soot_jimple_parser_node_TDiv_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TDiv$sub_refs	_jc_soot_jimple_parser_node_TDiv$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TDiv$sub_nonrefs	_jc_soot_jimple_parser_node_TDiv$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TDiv$refs	_jc_soot_jimple_parser_node_TDiv$refs;
typedef struct _jc_soot_jimple_parser_node_TDiv$nonrefs	_jc_soot_jimple_parser_node_TDiv$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TDiv$object	_jc_soot_jimple_parser_node_TDiv$object;

typedef const struct _jc_soot_jimple_parser_node_TDiv$vmethods	_jc_soot_jimple_parser_node_TDiv$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TDiv$vtable	_jc_soot_jimple_parser_node_TDiv$vtable;
typedef const struct _jc_soot_jimple_parser_node_TDiv$vtype	_jc_soot_jimple_parser_node_TDiv$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TDiv$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TDiv$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_TDiv$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TDiv$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TDiv$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TDiv$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TDiv$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_TDiv$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TDiv$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *) _JC_JCNI_ATTR;
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_soot_jimple_parser_node_TDiv$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_TDiv$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TDiv$vmethods	soot_jimple_parser_node_TDiv;
};

// Vtype
struct _jc_soot_jimple_parser_node_TDiv$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TDiv$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TDiv$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TDiv$refs {
    _jc_soot_jimple_parser_node_TDiv$sub_refs	soot_jimple_parser_node_TDiv;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TDiv$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TDiv$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TDiv$sub_nonrefs	soot_jimple_parser_node_TDiv;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TDiv$object {
	_jc_soot_jimple_parser_node_TDiv$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TDiv$vtype	*vtype;
	_jc_soot_jimple_parser_node_TDiv$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TDiv$vtype _jc_soot_jimple_parser_node_TDiv$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TDiv, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TDiv$class_object;

#endif	/* _JC_soot_jimple_parser_node_TDiv_H_ */
